@@ -417,15 +417,18 @@ my $__extract_rust_info = sub ($file, $grant, $current_dir) {
 
     if ($cargotoml->is_file) {
         my $toml = $cargotoml->slurp_utf8;
-        my $data = from_toml($toml);
+        my $data_raw = from_toml($toml);
+
+        # cope with https://doc.rust-lang.org/cargo/reference/workspaces.html
+        my $data = $data_raw->{workspace} // $data_raw;
         my $license = $data->{'package'}{'license'};
         my $authors = $data->{'package'}{'authors'} // [];
 
-        if (@$authors) {
+        if (ref($authors) eq 'ARRAY' and @$authors) {
             $grant->copyright(new_sc(join("\n", @$authors)));
         }
 
-        if (defined $license) {
+        if (defined $license and ref($license) eq '') {
             # Cargo.toml spells AND and OR in capitals
             # and allows / as a synonym to OR
             $license =~ s! AND ! and !g;
